@@ -1,4 +1,4 @@
-from mock import sentinel, MagicMock
+from mock import sentinel
 from unittest2 import TestCase
 import itertools
 
@@ -30,7 +30,7 @@ class SimpleTestCase(object):
         self.cleanups.append(func)
 
 
-class DummyTest(Exam, SimpleTestCase):
+class MyTestCase(Exam, SimpleTestCase):
 
     @patcher('tests.dummy.thing')
     def dummy_thing(self):
@@ -40,38 +40,54 @@ class DummyTest(Exam, SimpleTestCase):
 
     def __init__(self):
         self.calls = []
-        super(DummyTest, self).__init__()
+        super(MyTestCase, self).__init__()
 
     @before
-    def append_one(self):
-        self.calls.append(1)
-
-    @after
-    def append_two(self):
-        self.calls.append(2)
-
-    @around
-    def append_5_then_6(self):
-        self.calls.append(5)
-        yield
-        self.calls.append(6)
-
-
-class ExtendedDummy(DummyTest):
+    def append_wine(self):
+        self.calls.append('merlot')
 
     @before
-    def append_3(self):
-        self.calls.append(3)
+    def append_self(self):
+        self.calls.append(type(self))
 
     @after
-    def append_4(self):
-        self.calls.append(4)
+    def append_number(self):
+        self.calls.append('2 in parent class')
+
+    @after
+    def append_person(self):
+        self.calls.append('jeff')
 
     @around
-    def append_7_then_8(self):
-        self.calls.append(7)
+    def fairy_tail(self):
+        self.calls.append('hansel')
         yield
-        self.calls.append(8)
+        self.calls.append('gretle')
+
+
+class ExtendedTestCase(MyTestCase):
+
+    @before
+    def append_cheese(self):
+        self.calls.append('chedder')
+
+    @after
+    def append_meat(self):
+        self.calls.append('salami')
+
+    @around
+    def movies(self):
+        self.calls.append('turner')
+        yield
+        self.calls.append('hootch')
+
+    @before
+    def append_self(self):
+        self.calls.append(type(self))
+
+    @after
+    def append_number(self):
+        self.calls.append('two in subclass')
 
 
 # TODO: Make the subclass checking just be a subclass of the test case
@@ -79,15 +95,15 @@ class TestExam(Exam, TestCase):
 
     @fixture
     def case(self):
-        return DummyTest()
+        return MyTestCase()
 
     @fixture
-    def subclass_case(self):
-        return ExtendedDummy()
+    def subclassed_case(self):
+        return ExtendedTestCase()
 
     @after
     def stop_patchers(self):
-        cleanups = (self.case.cleanups, self.subclass_case.cleanups)
+        cleanups = (self.case.cleanups, self.subclassed_case.cleanups)
 
         for cleanup in itertools.chain(*cleanups):
             if hasattr(cleanup.im_self, 'is_local'):  # Is the mock started?
@@ -104,34 +120,34 @@ class TestExam(Exam, TestCase):
     def test_before_adds_each_method_to_set_up(self):
         expect(self.case.calls).to == []
         self.case.setUp()
-        expect(self.case.calls).to == [1]
+        expect(self.case.calls).to == [MyTestCase, 'merlot']
 
     def test_after_adds_each_method_to_tear_down(self):
         expect(self.case.calls).to == []
         self.case.tearDown()
-        expect(self.case.calls).to == [2]
+        expect(self.case.calls).to == ['jeff', '2 in parent class']
 
     def test_around_calls_methods_before_and_after_run(self):
         expect(self.case.calls).to == []
         self.case.run()
-        expect(self.case.state_when_run).to == [5]
-        expect(self.case.calls).to == [5, 6]
+        expect(self.case.state_when_run).to == ['hansel']
+        expect(self.case.calls).to == ['hansel', 'gretle']
 
     def test_before_works_on_subclasses(self):
-        expect(self.subclass_case.calls).to == []
-        self.subclass_case.setUp()
-        expect(self.subclass_case.calls).to == [3, 1]
+        expect(self.subclassed_case.calls).to == []
+        self.subclassed_case.setUp()
+        expect(self.subclassed_case.calls).to == ['merlot', 'chedder', ExtendedTestCase]
 
     def test_after_works_on_subclasses(self):
-        expect(self.subclass_case.calls).to == []
-        self.subclass_case.tearDown()
-        expect(self.subclass_case.calls).to == [4, 2]
+        expect(self.subclassed_case.calls).to == []
+        self.subclassed_case.tearDown()
+        expect(self.subclassed_case.calls).to == ['jeff', 'salami', 'two in subclass']
 
     def test_around_works_with_subclasses(self):
-        expect(self.subclass_case.calls).to == []
-        self.subclass_case.run()
-        expect(self.subclass_case.state_when_run).to == [7, 5]
-        expect(self.subclass_case.calls).to == [7, 5, 8, 6]
+        expect(self.subclassed_case.calls).to == []
+        self.subclassed_case.run()
+        expect(self.subclassed_case.state_when_run).to == ['hansel', 'turner']
+        expect(self.subclassed_case.calls).to == ['hansel', 'turner', 'hootch', 'gretle']
 
     def test_patcher_start_value_is_added_to_case_dict_on_setup(self):
         self.case.setUp()
@@ -146,9 +162,9 @@ class TestExam(Exam, TestCase):
 
     def test_patcher_lifecycle_works_on_subclasses(self):
         expect(self.other_thing).to != sentinel.mock
-        self.subclass_case.setUp()
+        self.subclassed_case.setUp()
         expect(self.other_thing).to == sentinel.mock
-        [cleanup() for cleanup in self.subclass_case.cleanups]
+        [cleanup() for cleanup in self.subclassed_case.cleanups]
         expect(self.other_thing).to != sentinel.mock
 
     def test_patcher_patches_with_a_magic_mock_if_no_function_decorated(self):
